@@ -251,6 +251,33 @@ class _CharacteristicsTypes:
         # r/o, Mirrors status of above
         ECOBEE_FAN_READ_SPEED = "48F62AEC-4171-4B4A-8F0E-1EEB6708B3FB"
 
+        # ConnectSense
+        # r/o, float - amps between 0 and 20
+        CONNECTSENSE_ENERGY_AMPS = "00000004-0000-1000-8000-001D4B474349"
+        # r/o, uint32 - state timer - in epoch format
+        CONNECTSENSE_STATE_TIMER = "00000005-0000-1000-8000-001D4B474349"
+        # r/o, unit32 - total amps
+        CONNECTSENSE_TOTAL_AMPS = "00000006-0000-1000-8000-001D4B474349"
+        # r/o, float - volts between 0 and 130
+        CONNECTSENSE_ENERGY_VOLTAGE = "00000008-0000-1000-8000-001D4B474349"
+        # r/o, float - amps between 0 and 20 on 20a in-wall outlet
+        CONNECTSENSE_ENERGY_AMPS_20 = "00000009-0000-1000-8000-001D4B474349"
+        # r/o, float - watts
+        CONNECTSENSE_ENERGY_WATT = "0000000A-0000-1000-8000-001D4B474349"
+        # r/o, int - power factor between 0 and 100
+        CONNECTSENSE_ENERGY_POWER_FACTOR = "0000000B-0000-1000-8000-001D4B474349"
+        # r/o, float - kilowatt hours between 0 and 7743802671740404396
+        CONNECTSENSE_ENERGY_KW_HOUR = "0000000C-0000-1000-8000-001D4B474349"
+        # r/o, string - outlet assigned name
+        CONNECTSENSE_ASSIGNED_NAME = "0000000E-0000-1000-8000-001D4B474349"
+        # r/o, uint32 - device type attached to outlet
+        CONNECTSENSE_DEVICE_TYPE = "0000000F-0000-1000-8000-001D4B474349"
+
+        # r/w, uint32, percentage
+        AQARA_GATEWAY_VOLUME = "EE56B186-B0D3-528E-8C79-C21FC9BCF437"
+        # r/w, bool
+        AQARA_PAIRING_MODE = "B1C09E4C-E202-4827-B343-B0F32F727CFF"
+
     def __init__(self) -> None:
         self.baseUUID = "-0000-1000-8000-0026BB765291"
         self._characteristics = {
@@ -492,7 +519,7 @@ class _CharacteristicsTypes:
             short = item_name.upper()
         else:
             if len(orig_item) == 36:
-                return orig_item
+                return orig_item.upper()
             raise KeyError(f"No UUID found for Item {orig_item}")
 
         medium = "0" * (8 - len(short)) + short
